@@ -1,16 +1,16 @@
 package Thread::Pool::Resolve;
 
-# Make sure we inherit from Thread::Pool
 # Make sure we have version info for this module
+# Make sure we inherit from Thread::Pool
 # Make sure we do everything by the book from now on
 
-our @ISA = qw(Thread::Pool);
-our $VERSION = '0.07';
+$VERSION = '0.08';
+@ISA = qw(Thread::Pool);
 use strict;
 
 # Make sure we only load stuff when we actually need it
 
-use AutoLoader 'AUTOLOAD';
+use load;
 
 # Make sure we can have a pool of threads
 
@@ -48,6 +48,12 @@ our @letter = split( '','abcdefghijklmnopqrstuvwxyz0123456789-' );
 
 #---------------------------------------------------------------------------
 
+# The following subroutines are loaded on demand only
+
+__END__
+
+#---------------------------------------------------------------------------
+
 # Class methods
 
 #---------------------------------------------------------------------------
@@ -153,12 +159,6 @@ sub new {
 
 #---------------------------------------------------------------------------
 
-# AutoLoader takes over from here
-
-__END__
-
-#---------------------------------------------------------------------------
-
 # Class methods
 
 #---------------------------------------------------------------------------
